/*
 * GPIO.c
 *
 *  Created on: Dec 16, 2012
 *      Author: jordi
 *
 *  This library allows use of GPIO for the upper half of port 0 (P016-P030)
 */

#include "LPC17xx.h"
#include "FreeRTOS.h"



/*****************************************************************************
** Function name:		GPIOSet
**
** Descriptions:		Set one GPIO as input or output
**
** parameters:			pin, direction (0 input, 1 output)
**
** Returned value:		None
**
*****************************************************************************/

void GPIOSet ( uint8_t pin , uint8_t direction ){

	/* We calculate the bit position to select the function on PINSEL register */
	uint8_t position = ( pin - 16 ) * 2;

	/* We write 00 to select GPIO function */

	LPC_PINCON->PINSEL1 &= ( ~( 3 << position ) );

	if ( direction == 0 ) LPC_GPIO0->FIODIR &= ( ~( 1 << pin ) ); // pin is selected as input

	if ( direction == 1 ) LPC_GPIO0->FIODIR |= ( 1 << pin ); // pin is selected as output

}


/*****************************************************************************
** Function name:		GPIOWrite
**
** Descriptions:		Writes a value on an output pin
**
** parameters:			pin, value to write ( 0 or 1 )
**
** Returned value:		None
**
*****************************************************************************/

void GPIOWrite ( uint8_t pin , uint8_t value ){

	if ( value == 0 ) LPC_GPIO0->FIOCLR = 1 << pin;

	if ( value == 1 ) LPC_GPIO0->FIOSET = 1 << pin;

}


/*****************************************************************************
** Function name:		GPIORead
**
** Descriptions:		Reads the value of an input pin
**
** parameters:			pin
**
** Returned value:		value of the input
**
*****************************************************************************/

uint32_t GPIORead ( uint8_t pin ){

	LPC_GPIO0->FIOMASK = ( ~( 1 << pin ) );

	return ( LPC_GPIO0->FIOPIN &  ( 1 << pin ) );

}
