/*
 * printf.c
 *
 *  Created on: Oct 21, 2012
 *      Author: jordi
 */

#include "LPC17xx.h"
#include "printf.h"
#include "uart.h"
#include <string.h>
#include <stdio.h>

#include "FreeRTOS.h"
#include "task.h"
#include "queue.h"
#include "semphr.h"


/* Declare a variable of type xSemaphoreHandle */
xSemaphoreHandle printMutex;


/*****************************************************************************
** Function name:		PrintText
**
** Descriptions:		Print a text
**
** parameters:			UART port, Pointer to the text to be printed
** Returned value:		None
**
*****************************************************************************/
void printfInit(){


	/* We create a mutex type semaphor to avoid concurrent access to printf */
	printMutex = xSemaphoreCreateMutex();

}
/*****************************************************************************
** Function name:		PrintText
**
** Descriptions:		Print a text
**
** parameters:			UART port, Pointer to the text to be printed
** Returned value:		None
**
*****************************************************************************/
void printText ( uint8_t port , char *Texte )
{

	/* Attempt to take the semaphore, blocking indefinitely if the mutex is not
	available immediately. */

	xSemaphoreTake ( printMutex, portMAX_DELAY );
	{

    UARTSend ( port, ( uint8_t *)Texte , strlen(Texte ) );

	}

	xSemaphoreGive ( printMutex );

	return;
}


/*****************************************************************************
** Function name:		PrintTextNum
**
** Descriptions:		Print a text and a number passed as a parameter
**
** parameters:			Pointer to the text, number value
** Returned value:		None
**
*****************************************************************************/

void printTextNum ( uint8_t port , char *Texte , signed int Num )
{
	char n[16];
	sprintf ( n , "%d\r\n" , Num );
	char *numero = n;
	int i = 0;

	while ( n[i] != '\0' ) i++;


	/* Attempt to take the semaphore, blocking indefinitely if the mutex is not
	available immediately */
	xSemaphoreTake ( printMutex, portMAX_DELAY );
	{

		UARTSend ( port , (uint8_t *)Texte , strlen ( Texte ) );
		UARTSend ( port , ( uint8_t * )numero , i );

	}

	xSemaphoreGive ( printMutex );


	return;

}


