/*
 * motor.c
 *
 *  Created on: Dec 6, 2012
 *      Author: jordi
 */

#include "LPC17xx.h"
#include <stdio.h>
#include <stdlib.h>
#include "printf.h"
#include "utilsLPC17xx.h"
#include "GPIO.h"

/* The pin on the LPC where the contact sensor will be connected */
uint8_t contactSensorPin = 27;

/* The serial port on the PLC where the motor driver will be connected */
uint8_t motorSerialPort = 1;

void motorInit ();
void motorMove ( uint8_t direction , uint8_t time );



/*****************************************************************************
** Function name:		motorInit
**
** Descriptions:		Initializes communication with motor and initializes sensor
**
** parameters:			none
**
** Returned value:		none
**
*****************************************************************************/

void motorInit (){

	/* We initialize serial communication with motor driver */
	UARTInit ( motorSerialPort , 115200 );

	/* We set the pin where the sensor is connected as an input */
	GPIOSet ( contactSensorPin , 0 );
}

/*****************************************************************************
** Function name:		motorMove
**
** Descriptions:		Move the motor in the requested direction
**
** parameters:			direction to move the motor ( 1 for forward, 0 for backward ),
** 						duration of the movement in msc.
**
** Returned value:		none
**
*****************************************************************************/

void motorMove ( uint8_t direction, uint8_t time ){

	if (direction ){

		printText ( 3 , "\r\nEns movem endavant!\r\n");

		/* We move motor forward */
		printText ( motorSerialPort , "2f9\r" );

		passiveDelayMs( time );

		/* We stop motor after the specified time */
		printText ( motorSerialPort, "2f0\r" );

		/* If the contact sensor detects a collision, we move backward */
		if ( ( GPIORead ( contactSensorPin ) ) != 0 ) motorMove ( 0 , time );

	}

	else{

		printText ( 3 , "\r\nEns movem endarrera!\r\n");

		/* We move motor backward */
		printText ( motorSerialPort , "2r9\r" );

		passiveDelayMs( time );

		/* We stop motor after the specified time */
		printText ( motorSerialPort , "2r0\r" );

	}

}

/*****************************************************************************
** Function name:		motorMoveActiveDelay
**
** Descriptions:		Move the motor in the requested direction. This version uses active delays,
** 						for cases when passive delays are not suitable
**
** parameters:			direction to move the motor ( 1 for forward, 0 for backward ),
** 						duration of the movement in msc.
**
** Returned value:		none
**
*****************************************************************************/

void motorMoveActiveDelay ( uint8_t direction, uint8_t time ){

	if (direction ){

		/* We move motor forward */
		printText ( motorSerialPort , "2f5\r" );

		delayMs( time );

		/* We stop motor after the specified time */
		printText ( motorSerialPort, "2f0\r" );

	}

	else{

		/* We move motor backward */
		printText ( motorSerialPort , "2r5\r" );

		delayMs( time );

		/* We stop motor after the specified time */
		printText ( motorSerialPort , "2r0\r" );

	}

}

