

/* Library includes. */
#include "LPC17xx.h"
#include <stdio.h>
#include <stdlib.h>
#include "driverWifly.h"
#include "uart.h"
#include "printf.h"
#include "utilsLPC17xx.h"

/* FreeRTOS.org includes. */
#include "FreeRTOS.h"
#include "task.h"
#include "queue.h"


/*The priorities at which the tasks will be created*/
#define	TASK_PRIORITY		( tskIDLE_PRIORITY + 1 )

/* The queue used by both tasks. */
static xQueueHandle xQueue = NULL;

/* The number of items the queue can hold */
#define mainQUEUE_LENGTH ( 10 )
#define ITEMS_LENGHT (20)

/* The tasks to be created*/
static void dataTask();
static void motorTask();

/* Function to search for maximum reception */
static void searchReception();


int main( void )
{

    /* Create the queue. */
    xQueue = xQueueCreate( mainQUEUE_LENGTH, ITEMS_LENGHT );

	/* Only create the tasks if the semaphore and the queue were created successfully. */
	if( xQueue != NULL)
	{

		/* Initializations */
		UARTInit ( 0 , 9600 ); // Wifly
		UARTInit ( 3 , 9600 ); // Console
		printfInit(); // printf function
		motorInit (); // Escalfem motors!
		connecInit(); // Internet connection

		/* We move to the point where we can get maximum reception */
		searchReception();

		/* Create the tasks */
		xTaskCreate ( dataTask , "DataGet" , 240 , NULL , TASK_PRIORITY , NULL );
		xTaskCreate( motorTask , "Motor" , 240 , NULL , TASK_PRIORITY+1 , NULL );

		/* Start the scheduler so the created tasks start executing. */
		vTaskStartScheduler();


	}

    /* If all is well we will never reach here as the scheduler will now be
    running the tasks.  If we do reach here then it is likely that there was
    insufficient heap memory available for a resource to be created. */
	for( ;; );
	return 0;
}
/*-----------------------------------------------------------*/


static void dataTask(){

	char data [16];

	for (;;){

			/* We request a data to the app */
			memset ( data , 0x00 , sizeof ( data ) );
			printText ( 3 , "\r\nSolicitant dada a la app...\r\n " );

			if ( reqData ( data ) ){
				printText ( 3 , "\r\nDada rebuda: ");
				printText ( 3, data);

				/*We send the command to the queue */
				printText ( 3, "\r\nEnviant dada a la cua...\r\n ");
				xQueueSend( xQueue, &data, portMAX_DELAY );
			}

	}

}

/*------------------------------------------------------------------*/

static void motorTask(){

	char data [16];
	uint8_t direction; //direction of movement
	const uint32_t time = 5000; //duration of movement

	for (;;){

			/* We receive the data from the queue */
			memset ( data , 0x00 , sizeof ( data ) );
			xQueueReceive( xQueue, &data, portMAX_DELAY );

			printText ( 3, "\r\nDada llegida de la cua: " );
			printText ( 3 , data );

			/* We check the data. If it's even, we move forward (1), else we move backwards (0) */
			direction = ( ( lastDigit (data) % 2 ) == 0 );
			motorMove ( direction , time );
	}


}

/* The function to search for the maximum reception. It doesn't take any parameters, and it
 * doesn't return anything */

static void searchReception(){

	const uint32_t time = 2000; //duration of movement
	uint8_t direction; // direction of movement, 1 for forward, 0 for backward
	int32_t sactual = wiflyGetRSSI();
	int32_t santerior = sactual;

	printText ( 3 , "\r\nBusquem on tenim la millor recepcio...");

	/* First we move forward till the signal varies */

	while ( sactual == santerior){

		motorMoveActiveDelay ( 1 , time );

		sactual = wiflyGetRSSI();

	}

	/* If signal has increased, we keep on moving forward. Otherwise we have to move backwards */

	direction = ( sactual > santerior );

	/* Now we keep on going on the right direction, until signal stops increasing */

	while ( sactual > santerior ){

		santerior = sactual;

		motorMoveActiveDelay ( direction , time );

		sactual = wiflyGetRSSI();

	}

	printText ( 3 , "\r\nPunt de millor recepcio trobat...");

}


void vApplicationMallocFailedHook( void )
{
	/* This function will only be called if an API call to create a task, queue
	or semaphore fails because there is too little heap RAM remaining. */

	printText ( 3, "\r\nNo es pot crear tasca, cua o semafor" );
	for( ;; );
}
/*-----------------------------------------------------------*/

void vApplicationStackOverflowHook( xTaskHandle *pxTask, signed char *pcTaskName )
{
	/* This function will only be called if a task overflows its stack.  Note
	that stack overflow checking does slow down the context switch
	implementation. */

	printText ( 3, "\r\nstack overflow nen" );
	for( ;; );
}
/*-----------------------------------------------------------*/

void vApplicationIdleHook( void )
{
	//printText ( 3, "\r\nIdleHook executant-se" );
}

/*-----------------------------------------------------------*/

void vApplicationTickHook( void )
{

}


