/*
 * utilsLPC17xx.c
 *
 *  Created on: Dec 6, 2012
 *      Author: jordi
 */


#include "LPC17xx.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "uart.h"
#include "utilsLPC17xx.h"

/* FreeRTOS.org includes. */
#include "FreeRTOS.h"
#include "task.h"


extern volatile uint8_t UART0Buffer[BUFSIZE];
extern volatile uint32_t UART0Count;


/*****************************************************************************
** Function name:		delayMs
**
** Descriptions:		Introduces an active delay
**
** parameters:			Number of milliseconds
** Returned value:		none
**
*****************************************************************************/

void delayMs( uint32_t ms ){

	uint32_t i;

	for ( i = 0; i < ( ( ( uint32_t ) 7140 ) *ms ); i++ ){
		;
	}


}

/*****************************************************************************
** Function name:		passiveDelayMs
**
** Descriptions:		Introduces a passive delay
**
** parameters:			Number of milliseconds
** Returned value:		none
**
*****************************************************************************/

void passiveDelayMs ( uint32_t ms ){

	vTaskDelay ( ms / portTICK_RATE_MS );

}

/*****************************************************************************
** Function name:		UARTScan
**
** Descriptions:		Listen for new characters received on UART0
**
** parameters:			Pointer to string where the characters will be stored, timeout
** Returned value:		Number of characters stored
**
*****************************************************************************/

uint8_t UARTScan ( char *resposta , uint32_t timeOut ){

		uint8_t newCount = 0 , oldCount;

		UART0Count = 0;

		LPC_UART0->IER = IER_THRE | IER_RLS | IER_RBR;	// enable interrupt RX UART0
		delayMs ( timeOut );	// wait sometime for receive some commands

		do {

		oldCount = newCount;
		delayMs ( 10 );
		newCount = UART0Count;

		} while ( oldCount != newCount ); // wait a little time while we have new char


		LPC_UART0->IER = IER_THRE | IER_RLS;	// disable interrupt RX UART0
		strncpy ( resposta , (char *) UART0Buffer, newCount );
		resposta[newCount] = 0;	// add end string. Now we have a string

		return newCount;

}



/*****************************************************************************
** Function name:		parseString
**
** Descriptions:		Search for the appearance of one string inside another
**
** parameters:			Pointer to string where to look, pointer to string to search
** Returned value:		Position of next character on first string after the first appearance of
** 						the second string. NULL if string not found
**
*****************************************************************************/

uint8_t parseString ( char *s1 , char *s2 ){

	uint8_t trobat = 0, i = 0, j = 0;

	while ( (  s1[i] != 0 ) & ( trobat == 0 ) ){ //Search till the end or till we found what we search
		if (  s1[i] ==  s2[j]  ){ 		//Fisrt character found
			while ( ( s1[i] != 0 ) & ( s1[i]  !=0 )){	//we look for the rest
				if ( s1[i] != s2[j] ) break;		//found character not matching
				else {
					i++;
					j++;
				}
			}
			if ( s2[j] == 0 ) trobat = 1;	//We finish search and all the characters match
			else j = 0;
		}

		else i++;
	}

	if ( trobat ) return i++;

	else return 0;

}


/*****************************************************************************
** Function name:		cutString
**
** Descriptions:		Remove all the characters after the specified character on a string
**
** parameters:			string,last character on the resulting string
** Returned value:		None
**
*****************************************************************************/

void cutString ( char *s , char final ){

	int j = 0;

	while ( s[j] != final ) j++;


	s[j] = 0;

}

/*****************************************************************************
**                            End Of File
******************************************************************************/



